@@ -1,4 +1,4 @@
-metacum <- function(x, pooled="fixed", sortvar, level=x$level, level.comb=x$level.comb){
+metacum <- function(x, pooled="fixed", sortvar){
   
   
   if (!inherits(x, "meta"))
@@ -13,22 +13,9 @@ metacum <- function(x, pooled="fixed", sortvar, level=x$level, level.comb=x$leve
   pooled <- c("fixed", "random")[imeth]
   
   
-  if (length(level)==0){
-    warning("level set to 0.95")
-    level <- 0.95
-  }
-  ##
-  if (length(level.comb)==0){
-    warning("level.comb set to 0.95")
-    level.comb <- 0.95
-  }
-  
-  
   k.all <- length(x$TE)
   sort <- !missing(sortvar)
-  
-  sm <- x$sm
-  
+
   if (!sort) sortvar <- rep(1, k.all)
 
   if (sort & length(sortvar) != k.all)
@@ -37,11 +24,9 @@ metacum <- function(x, pooled="fixed", sortvar, level=x$level, level.comb=x$leve
   
   n.e <- x$n.e
   n.c <- x$n.c
-  n   <- x$n
   ##
   event.e <- x$event.e
   event.c <- x$event.c
-  event   <- x$event
   ##
   mean.e <- x$mean.e
   mean.c <- x$mean.c
@@ -62,11 +47,9 @@ metacum <- function(x, pooled="fixed", sortvar, level=x$level, level.comb=x$leve
     ##
     n.e <- n.e[o]
     n.c <- n.c[o]
-    n   <- n[o]
     ##
     event.e <- event.e[o]
     event.c <- event.c[o]
-    event   <- event[o]
     ##
     mean.e <- mean.e[o]
     mean.c <- mean.c[o]
@@ -82,7 +65,7 @@ metacum <- function(x, pooled="fixed", sortvar, level=x$level, level.comb=x$leve
   }
 
   
-  res.i <- matrix(NA, ncol=6, nrow=k.all)
+  res.i <- matrix(NA, ncol=4, nrow=k.all)
   ##
   for (i in 1:k.all){
     sel <- 1:i
@@ -95,82 +78,52 @@ metacum <- function(x, pooled="fixed", sortvar, level=x$level, level.comb=x$leve
       ##
       oldopt <- options(warn=-1)
       m <- metabin(event.e[sel], n.e[sel], event.c[sel], n.c[sel],
-                   method=x$method, sm=sm,
+                   method=x$method, sm=x$sm,
                    incr=x$incr, allincr=x$allincr, addincr=x$addincr,
                    allstudies=x$allstudies, MH.exact=x$MH.exact,
                    RR.cochrane=x$RR.cochrane,
-                   level=level, level.comb=level.comb,
                    warn=x$warn)
       options(oldopt)
     }
     ##
     if (inherits(x, "metacont")){
       m <- metacont(n.e[sel], mean.e[sel], sd.e[sel],
-                    n.c[sel], mean.c[sel], sd.c[sel], sm=sm,
-                    level=level, level.comb=level.comb)
+                    n.c[sel], mean.c[sel], sd.c[sel], sm=x$sm)
     }
     ##
     if (inherits(x, "metagen")){
-      m <- metagen(TE[sel], seTE[sel], sm=sm,
-                   level=level, level.comb=level.comb)
+      m <- metagen(TE[sel], seTE[sel], sm=x$sm)
     }
     ##
-    if (inherits(x, "metaprop")){
-      m <- metaprop(event[sel], n[sel],
-                    studlab=studlab[sel],
-                    freeman.tukey=x$freeman.tukey,
-                    level=level, level.comb=level.comb)
-      sm <- "AS prop"
-    }
-    ##
-    tsum.i <- summary(m)
+    tres <- summary(m)
     ##
     if (pooled == "fixed"){
       res.i[i,] <- c(m$TE.fixed, m$seTE.fixed,
-                     tsum.i$fixed$p, tsum.i$I2$TE,
-                     tsum.i$tau, sum(m$w.fixed, na.rm=TRUE))
+                     tres$fixed$p, tres$I2$TE)
+      TE.sum <- x$TE.fixed
+      seTE.sum <- x$seTE.fixed
+      pval.sum <- summary(x)$fixed$p
     }
-    ##
-    else if (pooled == "random"){
+    if (pooled == "random"){
       res.i[i,] <- c(m$TE.random, m$seTE.random,
-                     tsum.i$random$p, tsum.i$I2$TE,
-                     tsum.i$tau, sum(m$w.random, na.rm=TRUE))
+                     tres$random$p, tres$I2$TE)
+      TE.sum <- x$TE.random
+      seTE.sum <- x$seTE.random
+      pval.sum <- summary(x)$random$p
     }
   }
   
   
-  tsum <- summary(x, level=level, level.comb=level.comb)
-  ##
-  if (pooled == "fixed"){
-    TE.sum <- x$TE.fixed
-    seTE.sum <- x$seTE.fixed
-    pval.sum <- tsum$fixed$p
-    w.sum <- sum(x$w.fixed, na.rm=TRUE)
-  }
-  ##
-  else if (pooled == "random"){
-    TE.sum <- x$TE.random
-    seTE.sum <- x$seTE.random
-    pval.sum <- tsum$random$p
-    w.sum <- sum(x$w.random, na.rm=TRUE)
-  }
-  
-  
-  ##  nlab <- nchar(studlab)
-  ##  nlabnr <- nchar(seq(along=studlab))
-  ##  ##
-  ##  slab <- character(k.all)
-  ##  for (i in 1:k.all)
-  ##    slab[i] <- paste("Adding ", studlab[i],
-  ##                     paste(rep(" ", max(nlab)-nlab[i]), collapse=""),
-  ##                     " (k=",
-  ##                     paste(rep(" ", max(nlabnr)-nlabnr[i]), collapse=""),
-  ##                     i, ")", sep="")
+  nlab <- nchar(studlab)
+  nlabnr <- nchar(seq(along=studlab))
   ##
   slab <- character(k.all)
   for (i in 1:k.all)
     slab[i] <- paste("Adding ", studlab[i],
-                     " (k=", i, ")", sep="")
+                     paste(rep(" ", max(nlab)-nlab[i]), collapse=""),
+                     " (k=",
+                     paste(rep(" ", max(nlabnr)-nlabnr[i]), collapse=""),
+                     i, ")", sep="")
   ##
   slab <- c(slab, "Pooled estimate")
   
@@ -178,16 +131,10 @@ metacum <- function(x, pooled="fixed", sortvar, level=x$level, level.comb=x$leve
               seTE=c(res.i[,2], NA, seTE.sum),
               studlab=c(rev(rev(slab)[-1]), " ", rev(slab)[1]),
               p.value=c(res.i[,3], NA, pval.sum),
-              w=c(res.i[,6], NA, w.sum),
-              I2=c(res.i[,4], NA, tsum$I2$TE),
-              tau=c(res.i[,5], NA, tsum$tau),
-              sm=sm, method=x$method, k=x$k,
-              pooled=pooled,
-              TE.fixed=NA, seTE.fixed=NA,
-              TE.random=NA, seTE.random=NA,
-              Q=NA, tau=NA,
-              level=level, level.comb=level.comb)
-  
+              I2=c(res.i[,4], NA, summary(x)$I2$TE),
+              sm=x$sm, method=x$method, k=x$k,
+              pooled=pooled)
+
   class(res) <- c("metacum", "meta")
   
   res
