@@ -1,34 +1,25 @@
 plot.meta <- function(x,
-                      byvar, bylab,
-                      print.byvar=TRUE,
-                      sortvar,
+                      byvar, bylab, sortvar,
                       studlab=TRUE,
-                      level=x$level,
-                      level.comb=x$level.comb,
-                      ##
-                      comb.fixed=FALSE, comb.random=FALSE,
-                      overall=comb.fixed|comb.random,
-                      text.fixed="Fixed effect model",
-                      text.random="Random effects model",
-                      lty.fixed=2, lty.random=3,
-                      ##
+                      level=0.95, level.comb=level,
+                      comb.f=FALSE, comb.r=FALSE,
+                      text.f="Fixed effect model",
+                      text.r="Random effects model",
+                      lty.f=2, lty.r=3,
                       xlab=NULL,
                       xlim, ylim, lwd=1, cex=1,
                       cex.comb=1.2*cex,
                       cex.axis=cex,
                       cex.lab=cex,
-		      log=ifelse(x$sm %in% c("RR", "OR", "HR"), "x", ""),
+		      log=ifelse(x$sm=="RR"|x$sm=="OR"|x$sm=="HR", "x", ""),
                       axes=TRUE,
                       allstudies=TRUE,
-                      weight=ifelse(comb.random, "random", "fixed"),
+                      weight="fixed",
                       scale.diamond=1,
                       scale.square=1,
                       col.i="black",
-                      clim=xlim,
-                      arrow.length=0.1,
-		      ref=ifelse(x$sm %in% c("RR", "OR", "HR"), 1, 0),
                       ...){
-  
+
   
   if (!inherits(x, "meta"))
     stop("Argument 'x' must be an object of class \"meta\"")
@@ -36,10 +27,9 @@ plot.meta <- function(x,
   
   oldpar <- par(las=1, mar=c(5.1, 2.1, 4.1, 2.1))
   on.exit(par(oldpar))
-  
-  
+
+
   if (inherits(x, "metainf")|inherits(x, "metacum")){
-    ##
     x$TE.fixed    <- rev(x$TE)[1]
     x$seTE.fixed  <- rev(x$seTE)[1]
     x$TE.random   <- rev(x$TE)[1]
@@ -49,12 +39,9 @@ plot.meta <- function(x,
     x$seTE <- rev(rev(x$seTE)[-(1:2)])
     x$studlab <- rev(rev(x$studlab)[-(1:2)])
     ##
-    if (x$pooled=="fixed")
-      text.fixed <- "Fixed effect model"
-    else
-      text.fixed <- "Random effects model"
-    ##
-    comb.fixed <- TRUE
+    if (x$pooled=="fixed") text.f <- "Fixed effect model"
+    else  text.f <- "Random effects model"
+    comb.f <- TRUE
   }
   
   sm <- x$sm
@@ -65,22 +52,22 @@ plot.meta <- function(x,
     else if (sm=="RD" ) xlab <- "Risk Difference"
     else if (sm=="RR" ) xlab <- "Relative Risk"
     else if (sm=="SMD") xlab <- "Standardised mean difference"
-    else if (sm=="WMD"|sm=="MD") xlab <- "Mean difference"
+    else if (sm=="WMD") xlab <- "Weighted mean difference"
     else if (sm=="HR" ) xlab <- "Hazard Ratio"
     else if (sm=="AS" ) xlab <- "Arcus Sinus Transformation"
-    else if (sm=="proportion" ) xlab <- "Proportion"
     else xlab <- sm
   }
-  
-  
-  iweight <- charmatch(tolower(weight),
-                       c("same", "fixed", "random"), nomatch = NA)
-  ##
-  if(is.na(iweight))
-    stop("weight should be \"same\", \"fixed\", or \"random\"")
-  ##
-  weight <- c("same", "fixed", "random")[iweight]
-  
+  ##  if (inherits(x, "meta")){
+  ##    if (sm == "OR"  & missing(xlab)) xlab <- "Odds Ratio"
+  ##    else if (sm == "RD"  & missing(xlab)) xlab <- "Risk Difference"
+  ##    else if (sm == "RR"  & missing(xlab)) xlab <- "Relative Risk"
+  ##    else if (sm == "SMD" & missing(xlab)) xlab <- "Standardised mean difference"
+  ##    else if (sm == "WMD" & missing(xlab)) xlab <- "Weighted mean difference"
+  ##    else if (sm == "HR"  & missing(xlab)) xlab <- "Hazard Ratio"
+  ##    else if (sm == "AS"  & missing(xlab)) xlab <- "Arcus Sinus Transformation"
+  ##    else xlab <- sm
+  ##  }
+
   
   ##
   ## total number of trials to plot (*not* number of trials combined)
@@ -94,12 +81,7 @@ plot.meta <- function(x,
   
   by <- !missing(byvar)
   sort <- !missing(sortvar)
-  
-  byvar.name <- deparse(substitute(byvar))
-  if (by)
-    if (!is.null(x[[byvar.name]]))
-      byvar <- x[[byvar.name]]
-  
+
   if (!by) byvar <- rep(1, k.all)
   if (!sort) sortvar <- rep(1, k.all)
 
@@ -125,28 +107,24 @@ plot.meta <- function(x,
   ##
   if (n.stud != sum(sel>0)) warning("n.stud != sum(sel)")
   ##
+  n.e <- x$n.e[sel]
+  n.c <- x$n.c[sel]
   ##
+  event.e <- x$event.e[sel]
+  event.c <- x$event.c[sel]
   ##
-  x$n <- x$n[sel]
-  x$n.e <- x$n.e[sel]
-  x$n.c <- x$n.c[sel]
+  mean.e <- x$mean.e[sel]
+  mean.c <- x$mean.c[sel]
   ##
-  x$event <- x$event[sel]
-  x$event.e <- x$event.e[sel]
-  x$event.c <- x$event.c[sel]
+  sd.e <- x$sd.e[sel]
+  sd.c <- x$sd.c[sel]
   ##
-  x$mean.e <- x$mean.e[sel]
-  x$mean.c <- x$mean.c[sel]
+  TE <- x$TE[sel]
+  seTE <- x$seTE[sel]
   ##
-  x$sd.e <- x$sd.e[sel]
-  x$sd.c <- x$sd.c[sel]
-  ##
-  x$TE <- x$TE[sel]
-  x$seTE <- x$seTE[sel]
-  ##
-  x$w.fixed <- x$w.fixed[sel]
-  x$w.random <- x$w.random[sel]
-  x$studlab <- studlab[sel]
+  w.fixed <- x$w.fixed[sel]
+  w.random <- x$w.random[sel]
+  studlab <- studlab[sel]
   ##
   byvar <- byvar[sel]
   sortvar <- sortvar[sel]
@@ -156,26 +134,24 @@ plot.meta <- function(x,
     ##
     o <- order(byvar, sortvar)
     ##
-    x$n <- x$n[o]
-    x$n.e <- x$n.e[o]
-    x$n.c <- x$n.c[o]
+    n.e <- n.e[o]
+    n.c <- n.c[o]
     ##
-    x$event <- x$event[o]
-    x$event.e <- x$event.e[o]
-    x$event.c <- x$event.c[o]
+    event.e <- event.e[o]
+    event.c <- event.c[o]
     ##
-    x$mean.e <- x$mean.e[o]
-    x$mean.c <- x$mean.c[o]
+    mean.e <- mean.e[o]
+    mean.c <- mean.c[o]
     ##
-    x$sd.e <- x$sd.e[o]
-    x$sd.c <- x$sd.c[o]
+    sd.e <- sd.e[o]
+    sd.c <- sd.c[o]
     ##
-    x$TE <- x$TE[o]
-    x$seTE <- x$seTE[o]
+    TE <- TE[o]
+    seTE <- seTE[o]
     ##
-    x$w.fixed <- x$w.fixed[o]
-    x$w.random <- x$w.random[o]
-    x$studlab <- x$studlab[o]
+    w.fixed <- w.fixed[o]
+    w.random <- w.random[o]
+    studlab <- studlab[o]
     ##
     byvar <- byvar[o]
     sortvar <- sortvar[o]
@@ -183,33 +159,23 @@ plot.meta <- function(x,
 
   
   by.levs <- unique(byvar)
+
   
-  
-  if (length(level)==0){
-    warning("level set to 0.95")
-    level <- 0.95
-  }
+  tres <- ci(TE, seTE, level)
+  TE <- tres$TE
+  lowTE <- tres$lower
+  uppTE <- tres$upper
   ##
-  if (length(level.comb)==0){
-    if (comb.fixed | comb.random)
-      warning("level.comb set to 0.95")
-    level.comb <- 0.95
-  }
-  
-  sum.meta <- summary(x, level=level, level.comb=level.comb, warn=FALSE)
+  tres <- ci(x$TE.fixed, x$seTE.fixed, level.comb)
+  TE.fixed <- tres$TE
+  lowTE.fixed <- tres$lower
+  uppTE.fixed <- tres$upper
   ##
-  TE <- sum.meta$study$TE
-  lowTE <- sum.meta$study$lower
-  uppTE <- sum.meta$study$upper
-  ##
-  TE.fixed <- sum.meta$fixed$TE
-  lowTE.fixed <- sum.meta$fixed$lower
-  uppTE.fixed <- sum.meta$fixed$upper
-  ##
-  TE.random <- sum.meta$random$TE
-  lowTE.random <- sum.meta$random$lower
-  uppTE.random <- sum.meta$random$upper
-  
+  tres <- ci(x$TE.random, x$seTE.random, level.comb)
+  TE.random <- tres$TE
+  lowTE.random <- tres$lower
+  uppTE.random <- tres$upper
+
   
   if (by){
 
@@ -221,9 +187,8 @@ plot.meta <- function(x,
       sel <- byvar == i
       ##
       if (inherits(x, "metabin")){
-        meta1 <- metabin(x$event.e[sel], x$n.e[sel],
-                         x$event.c[sel], x$n.c[sel],
-                         method=x$method, sm=x$sm,
+        meta1 <- metabin(event.e[sel], n.e[sel], event.c[sel], n.c[sel],
+                         method=x$method, sm=sm,
                          incr=x$incr, allincr=x$allincr,
                          addincr=x$addincr, allstudies=x$allstudies,
                          MH.exact=x$MH.exact, RR.cochrane=x$RR.cochrane,
@@ -231,18 +196,13 @@ plot.meta <- function(x,
       }
       ##
       if (inherits(x, "metacont")){
-        meta1 <- metacont(x$n.e[sel], x$mean.e[sel], x$sd.e[sel],
-                          x$n.c[sel], x$mean.c[sel], x$sd.c[sel],
-                          sm=x$sm)
+        meta1 <- metacont(n.e[sel], mean.e[sel], sd.e[sel],
+                          n.c[sel], mean.c[sel], sd.c[sel],
+                          sm=sm)
       }
       ##
       if (inherits(x, "metagen")){
-        meta1 <- metagen(x$TE[sel], x$seTE[sel], sm=x$sm)
-      }
-      ##
-      if (inherits(x, "metaprop")){
-        meta1 <- metaprop(event=x$event[sel], n=x$n[sel],
-                          freeman.tukey=x$freeman.tukey)
+        meta1 <- metagen(TE[sel], seTE[sel], sm=sm)
       }
       ##
       res.w[j,] <- c(meta1$TE.fixed, meta1$seTE.fixed,
@@ -266,21 +226,17 @@ plot.meta <- function(x,
     by.levs <- by.levs[sel]
     k.all.w <- k.all.w[sel]
     ##
-    if (comb.fixed | !(comb.fixed|comb.random)){
-      if (comb.random)
-        warning("Estimate from fixed effect model used in groups defined by 'byvar'")
+    if (comb.f | !(comb.f|comb.r)){
+      if (comb.r) warning("FE estimate used in groups defined by 'byvar'")
       ##
-      meta.w <- ci(TE.fixed.w, seTE.fixed.w, level)
-      text.by <- text.fixed
-    }
-    if (!comb.fixed & comb.random){
-      meta.w <- ci(TE.random.w, seTE.random.w, level)
-      text.by <- text.random
+      tres <- ci(TE.fixed.w, seTE.fixed.w, level)
     }
+    if (!comb.f & comb.r)
+      tres <- ci(TE.random.w, seTE.random.w, level)
     ##
-    TE.w <- meta.w$TE
-    lowTE.w <- meta.w$lower
-    uppTE.w <- meta.w$upper
+    TE.w <- tres$TE
+    lowTE.w <- tres$lower
+    uppTE.w <- tres$upper
   }
   
   
@@ -288,30 +244,22 @@ plot.meta <- function(x,
   else n.by <- 0
 
   
-  if (comb.fixed & comb.random){
+  if (comb.f & comb.r){
     dy.comb <- 3.0
     yTE.fixed <- -0.5
     yTE.random <- -2.0
   }
-  if (comb.fixed & !comb.random){
+  if (comb.f & !comb.r){
     dy.comb <- 1.5
     yTE.fixed <- -0.5
   }
-  if (!comb.fixed & comb.random){
+  if (!comb.f & comb.r){
     dy.comb <- 1.5
     yTE.random <- -0.5
   }
-  if (!comb.fixed & !comb.random){
+  if (!comb.f & !comb.r){
     dy.comb <- 0
   }
-  if (!overall){
-    dy.comb <- 0
-  }
-  
-  
-  if (!comb.fixed) text.fixed <- ""
-  if (!comb.random) text.random <- ""
-  
   
   ##
   ## Plot symbol
@@ -320,9 +268,9 @@ plot.meta <- function(x,
     cex.i <- rep(cex, n.stud)
   else
     if (weight=="fixed")
-      cex.i <- 3*x$w.fixed/max(x$w.fixed)*scale.square
+      cex.i <- 3*w.fixed/max(w.fixed)*scale.square
     else
-      cex.i <- 3*x$w.random/max(x$w.random)*scale.square
+      cex.i <- 3*w.random/max(w.random)*scale.square
 
 
   ##
@@ -347,7 +295,7 @@ plot.meta <- function(x,
     yTE.w <- rev((1:N)[!sel][2+cumsum(c(0, rep(rows.w, n.by-1)))])
     ##
     ##
-    if ( (!comb.fixed & !comb.random) | !overall ){
+    if (!comb.f & !comb.r){
       yTE <- yTE - 1
       yTE.w <- yTE.w - 1
       N <- N-1
@@ -360,7 +308,9 @@ plot.meta <- function(x,
   dy <- 0.25*scale.diamond
 
   
-  if (sm %in% c("RR", "OR", "HR")){
+  if (sm == "RR" | sm == "OR" | sm == "HR"){
+    TE.null <- 1
+    ##
     TE <- exp(TE)
     lowTE <- exp(lowTE)
     uppTE <- exp(uppTE)
@@ -379,27 +329,8 @@ plot.meta <- function(x,
       uppTE.w <- exp(uppTE.w)
     }
   }
-  
-  
-  if (inherits(x, "metaprop")){
-    ref <- NA
-    ##
-    denum <- 1 + x$freeman.tukey
-    ##
-    TE.fixed <- sin(TE.fixed/denum)^2
-    lowTE.fixed <- sin(lowTE.fixed/denum)^2
-    uppTE.fixed <- sin(uppTE.fixed/denum)^2
-    ##
-    TE.random <- sin(TE.random/denum)^2
-    lowTE.random <- sin(lowTE.random/denum)^2
-    uppTE.random <- sin(uppTE.random/denum)^2
-    ##
-    if (by){
-      TE.w <- sin(TE.w/denum)^2
-      lowTE.w <- sin(lowTE.w/denum)^2
-      uppTE.w <- sin(uppTE.w/denum)^2
-    }
-  }
+  else TE.null <- 0
+
   
   ##
   ## x-axis:
@@ -408,36 +339,16 @@ plot.meta <- function(x,
     xlim <- c(min(lowTE, na.rm=TRUE), max(uppTE, na.rm=TRUE))
 
   
-  ##
-  ## Change code to create bylab
-  ## (sc, 4.6.2008)
-  ##
-  ##if (missing(bylab))
-  ##  bylab <- paste("byvar", by.levs, sep=" = ")
-  ##else
-  ##  bylab <- paste(bylab, by.levs, sep=" = ")
-  ##
-  if (print.byvar){
-    if (missing(bylab))
-      bylab <- paste(byvar.name,
-                     " = ",
-                     format(by.levs), sep="")
-    else
-      bylab <- paste(bylab,
-                     " = ",
-                     format(by.levs), sep="")
-  }
-  else
-    bylab <- format(by.levs)
+  if (missing(bylab)) bylab <- paste("byvar", by.levs, sep=" = ")
+  else bylab <- paste(bylab, by.levs, sep=" = ")
 
   
   ##
   ## Forest plot
   ##
-  plot(NA, NA,
-       xlim=xlim, ylim=ylim, log=log,
-       xlab="", ylab="", type="n", axes=FALSE,
-       ...)
+  plot(NA, NA, xlim=xlim, ylim=ylim,
+       xlab="", ylab="", type="n", log=log,
+       axes=FALSE, ...)
   
   ##
   ## Add axis
@@ -450,103 +361,76 @@ plot.meta <- function(x,
   ##
   ## Add no effect line
   ##
-  ##abline(v=ref, lty=2, lwd=2, col="dimgray")
-  abline(v=ref, lty=1, lwd=lwd)
+  ##abline(v=TE.null, lty=2, lwd=2, col="dimgray")
+  abline(v=TE.null, lty=1, lwd=lwd)
+
   
   ##
   ## Add line at pooled effect
   ##
-  if (comb.fixed)
+  if (comb.f)
     segments(TE.fixed, yTE.fixed+dy, TE.fixed, N,
-             lty=lty.fixed, lwd=lwd, col="dimgray")
-  if (comb.random)
+             lty=lty.f, lwd=2, col="dimgray")
+  if (comb.r)
     segments(TE.random, yTE.random+dy, TE.random, N,
-             lty=lty.random, lwd=lwd, col="dimgray")
+             lty=lty.r, lwd=2, col="dimgray")
   ##  if (inherits(x, "metainf")|inherits(x, "metacum"))
   ##    abline(v=TE.fixed, lty=3, lwd=2, col="dimgray")
-  
+
   ##
   ## Add single trial results
   ##
-  if (length(col.i) == 1)
-    col.i <- rep(col.i, length(TE))
-  ##
+  if (length(col.i) == 1) col.i <- rep(col.i, length(TE))
   for ( i in seq(along=TE)){
     if (cex.i[i] < 0.3)
       points(TE[i], yTE[i], pch=3, col=col.i[i], lwd=lwd)
     else
       points(TE[i], yTE[i], cex=as.numeric(cex.i[i]), pch=15, col=col.i[i])
   }
-  
   ##
   ## Plot confidence intervals
   ##
-  ## Cut confidence limits at value of clim
-  ## and add arrows at that position
-  ## (add by sc, 4.6.2008):
-  ##
-  ##segments(lowTE, yTE, uppTE, yTE, lwd=lwd, col=col.i)
-  ##
-  for (i in 1:length(lowTE)){
-    if (!is.na(lowTE[i])){
-      if (lowTE[i] < clim[1])
-        arrows(TE[i], yTE[i], clim[1], yTE[i],
-               lwd=lwd, col=col.i, length=arrow.length)
-      else
-        segments(lowTE[i], yTE[i], TE[i], yTE[i],
-                 lwd=lwd, col=col.i)
-      ##
-      if (uppTE[i] > clim[2])
-        arrows(TE[i], yTE[i], clim[2], yTE[i],
-               lwd=lwd, col=col.i, length=arrow.length)
-      else
-        segments(TE[i], yTE[i], uppTE[i], yTE[i],
-                 lwd=lwd, col=col.i)
-    }
-  }
-  
+  segments(lowTE, yTE, uppTE, yTE, lwd=lwd, col=col.i)
   ##
   ## Add trial labels
   ##
-  mtext(x$studlab, side=2, line=-0.2, outer=FALSE,
+  mtext(studlab, side=2, line=-0.2, outer=FALSE,
         at=yTE+0.25, adj=0, cex=0.7*cex)
-  
+
   ##
   ## Add group results
   ##
   if (by){
     ##
-    if (comb.fixed|comb.random){
-      for ( i in 1:length(lowTE.w)){
-        polygon(c(lowTE.w[i], TE.w[i], uppTE.w[i], TE.w[i]),
-                c(yTE.w[i], yTE.w[i]-dy, yTE.w[i], yTE.w[i]+dy),
-                col="lightgray")
-      }
+    for ( i in 1:length(lowTE.w)){
+      polygon(c(lowTE.w[i], TE.w[i], uppTE.w[i], TE.w[i]),
+              c(yTE.w[i], yTE.w[i]-dy, yTE.w[i], yTE.w[i]+dy),
+              col="lightgray")
     }
     ##
     mtext(bylab,
           side=2, line=-0.2, outer=FALSE,
           at=yTE.w+0.25,
-          adj=0, cex=0.7*cex)
+          adj=0, cex=0.8*cex)
   }
 
   ##
   ## Add pooled estimates
   ##
-  if (comb.fixed & overall){
+  if (comb.f){
     ##
     ## FE estimate
     ##
     polygon(c(lowTE.fixed, TE.fixed, uppTE.fixed, TE.fixed),
             c(yTE.fixed, yTE.fixed-dy, yTE.fixed, yTE.fixed+dy),
             col="black")
-    
-    mtext(text.fixed,
+
+    mtext(text.f,
           side=2, line=-0.2, outer=FALSE,
           at=yTE.fixed+0.25, adj=0, cex=cex.comb)
   }
   ##
-  if (comb.random & overall){
+  if (comb.r){
     ##
     ## RE estimate
     ##
@@ -554,7 +438,7 @@ plot.meta <- function(x,
             c(yTE.random, yTE.random-dy, yTE.random, yTE.random+dy),
             col="darkgray")
     ##
-    mtext(text.random, 
+    mtext(text.r, 
           side=2, line=-0.2, outer=FALSE,
           at=yTE.random+0.25, adj=0, cex=cex.comb)
   }
